    "-arin",	"whois.arin.net",
    "-ripe",	"whois.ripe.net",
    "-mnt",	"whois.ripe.net",
    "-lacnic",	"whois.lacnic.net",
    "-afrinic",	"whois.afrinic.net",
    "-ap",	"whois.apnic.net",
    "-cznic",	"whois.nic.cz",
    "-dk",	"whois.dk-hostmaster.dk",
    "-il",	"whois.isoc.org.il",
    "-is",	"whois.isnic.is",
    "-kg",	"whois.domain.kg",
    "-coop",	"whois.nic.coop",
    "-frnic",	"whois.nic.fr",
    "-lrms",	"whois.afilias.info",
    "-metu",	"whois.nic.tr",
    "-nicat",	"whois.nic.at",
    "-nicci",	"whois.nic.ci",
    "-irnic",	"whois.nic.ir",
    "-norid",	"whois.norid.no",
    "-tel",	"whois.nic.tel",
    "-adnic",	"whois.nic.org.uy",
    "-sixxs",	"whois.sixxs.net",
